export default class ChatbotBackend {
    constructor(chatbotId) {
        this.chatbotId = chatbotId;
    }

    async fetchChatbotDetails() {
        const existingSessionId = localStorage.getItem('otemateSessionId') ?? '';
        const response = await fetch(`https://otemate.xyz/api/init-chat/${this.chatbotId}?session_id=${existingSessionId}`);
        if (!response.ok) {
            throw new Error('Failed to fetch chatbot details');
        }
        return await response.json();
    }

    sendMessage(input, displayBotResponse, disableSendButton, enableSendButton) {
        if (!input.trim()) {
            alert('Please type a message before sending.');
            return;
        }

        const newMessage = `<div class="one-message-client">${input}</div>`;
        document.getElementById('chat-messages').innerHTML += newMessage;

        const chatMessages = document.getElementById('chat-messages');
        chatMessages.scrollTop = chatMessages.scrollHeight;

        // Clear input field
        document.getElementById('chat-input').value = '';

        disableSendButton();

        // Display loading message
        const loadingMessage = `<div class="one-message-system" id="loading-message">Typing...</div>`;
        document.getElementById('chat-messages').innerHTML += loadingMessage;
        const existingSessionId = localStorage.getItem('otemateSessionId') ?? '';

        fetch('https://otemate.xyz/api/chat', {
            method: 'POST',
            headers: {
                'Content-Type': 'application/json',
            },
            body: JSON.stringify({
                message: input,
                assistant_id: this.chatbotId,
                session_id: existingSessionId
            })
        })
            .then(response => response.json())
            .then(data => {
                document.getElementById('loading-message').remove();
                displayBotResponse(data.response);
                document.getElementById('chat-input').focus();

                if(data.new_session){
                    localStorage.setItem('otemateSessionId', data.new_session);
                }
            })
            .catch(error => {
                console.error('Error:', error);
                document.getElementById('loading-message').remove();
                displayBotResponse('Error sending message.');
            })
            .finally(() => {
                enableSendButton();
            });
    }
}
