export default class ChatbotUI {
    constructor(chatbotId) {
        this.chatbotId = chatbotId;
    }

    init(chatbotDetails) {
        this.injectStyles();
        this.createChatUI(chatbotDetails);
    }

    injectStyles() {
        const chatbotStyles = `
            #floating-chatbot {
                position: fixed;
                bottom: 20px;
                right: 20px;
                width: 350px;
                height: 450px;
                background-color: white;
                border: 2px solid #ccc;
                border-radius: 10px;
                box-shadow: 0 4px 8px rgba(0,0,0,0.2);
                display: none;
                flex-direction: column;
                z-index: 9999;
            }
            #chatbot-header {
                background-color: #007bff;
                color: white;
                padding: 10px;
                display: flex;
                justify-content: space-between;
                align-items: center;
                border-radius: 10px 10px 0 0;
            }
            #chatbot-body {
                flex: 1;
                padding: 10px;
                display: flex;
                flex-direction: column;
                justify-content: space-between;
            }
            #chat-messages {
                flex-grow: 1;
                overflow-y: auto;
                margin-bottom: 10px;
                max-height: 300px;
            }
            #chat-input-container {
                display: flex;
                align-items: center;
            }
            #chat-input {
                flex-grow: 1;
                padding: 10px;
                border: 1px solid #ccc;
                border-radius: 5px;
            }
            #send-message {
                background-color: #007bff;
                color: white;
                border: none;
                padding: 10px;
                margin-left: 5px;
                border-radius: 5px;
                cursor: pointer;
            }
            #close-chatbot {
                background: none;
                border: none;
                color: white;
                cursor: pointer;
            }
            #minimize-button {
                position: fixed;
                bottom: 20px;
                right: 20px;
                background-color: #007bff;
                color: white;
                border: none;
                border-radius: 50%;
                padding: 10px;
                font-size: 20px;
                cursor: pointer;
                z-index: 9999;
            }
            .one-message-system, .one-message-client {
                margin-bottom: 10px;
                padding: 10px 15px;
                border-radius: 20px;
                max-width: 80%;
                font-size: 14px;
                line-height: 1.5;
                word-wrap: break-word;
            }
            .one-message-system {
                background-color: #9E9E9E;
                color: #000000;
                align-self: flex-start;
                margin-left: 10px;
                text-align: left;
            }
            .one-message-client {
                background-color: #c8e6c9;
                color: #000000;
                align-self: flex-end;
                margin-left: 50px;
                text-align: left;
            }
        
            .chat-messages::-webkit-scrollbar {
                width: 4px;
            }
        
            .chat-messages::-webkit-scrollbar-thumb {
                background-color: #ccc;
                border-radius:23px;
            }
        
            .chat-messages::-webkit-scrollbar-track {
                background-color: #f5f5f5;
            }
        
            #contact-form {
                background-color: #f1f1f1;
                padding: 20px;
                border-radius: 5px;
                margin-top: 10px;
            }
        
            #contact-form label {
                display: block;
                margin: 10px 0 5px;
            }
        
            #contact-form input, #contact-form textarea {
                width: 100%;
                padding: 10px;
                margin-bottom: 5px;
                border-radius: 5px;
                border: 1px solid #ccc;
            }
        
            #contact-form button {
                background-color: #007bff;
                color: white;
                border: none;
                padding: 5px 10px;
                border-radius: 5px;
                cursor: pointer;
                margin-right: 10px;
            }
        
            #contact-form button:hover {
                background-color: #0056b3;
            }
        
            #contact-form #cancel-form {
                background-color: #ccc;
                color: black;
            }
        
            #contact-form #cancel-form:hover {
                background-color: #999;
            }
        
            .get-in_touch{
                border-radius: 5px;
                background-color: #8F3A84;
                color: #ffffff;
            }
        `;
        const styleTag = document.createElement('style');
        styleTag.innerHTML = chatbotStyles;
        document.head.appendChild(styleTag);
    }

    createChatUI(chatbotDetails) {
        const chatbotContainer = document.createElement('div');

        chatbotContainer.innerHTML = `
            <button id="minimize-button" aria-label="Open chatbot">
                <svg xmlns="http://www.w3.org/2000/svg" width="50" height="40" fill="currentColor" class="bi bi-chat-dots" viewBox="0 0 16 16">
                    <path d="M5 8a1 1 0 1 1-2 0 1 1 0 0 1 2 0m4 0a1 1 0 1 1-2 0 1 1 0 0 1 2 0m3 1a1 1 0 1 0 0-2 1 1 0 0 0 0 2"/>
                    <path d="m2.165 15.803.02-.004c1.83-.363 2.948-.842 3.468-1.105A9 9 0 0 0 8 15c4.418 0 8-3.134 8-7s-3.582-7-8-7-8 3.134-8 7c0 1.76.743 3.37 1.97 4.6a10.4 10.4 0 0 1-.524 2.318l-.003.011a11 11 0 0 1-.244.637c-.079.186.074.394.273.362a22 22 0 0 0 .693-.125m.8-3.108a1 1 0 0 0-.287-.801C1.618 10.83 1 9.468 1 8c0-3.192 3.004-6 7-6s7 2.808 7 6-3.004 6-7 6a8 8 0 0 1-2.088-.272 1 1 0 0 0-.711.074c-.387.196-1.24.57-2.634.893a11 11 0 0 0 .398-2"/>
                </svg>
            </button>
            <div id="floating-chatbot" role="dialog" aria-labelledby="chatbot-header">
                <div id="chatbot-header">
                    <span>${chatbotDetails.name}</span>
                    <button id="close-chatbot" aria-label="Close chatbot">
                        <svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" class="bi bi-x-lg" viewBox="0 0 16 16">
                            <path d="M2.146 2.854a.5.5 0 1 1 .708-.708L8 7.293l5.146-5.147a.5.5 0 0 1 .708.708L8.707 8l5.147 5.146a.5.5 0 0 1-.708.708L8 8.707l-5.146 5.147a.5.5 0 0 1-.708-.708L7.293 8z"/>
                        </svg>
                    </button>
                </div>
                <div id="chatbot-body">
                    <div id="chat-messages">
                        <div class="one-message-system">Welcome to our Support. How may I assist you?</div>
                    </div>
                    <div id="chat-input-container">
                        <textarea id="chat-input" placeholder="Type your message..." aria-label="Chat input"></textarea>
                        <button id="send-message" aria-label="Send message">
                            <svg xmlns="http://www.w3.org/2000/svg" width="16" height="16" fill="currentColor" class="bi bi-send" viewBox="0 0 16 16">
                                <path d="M15.854.146a.5.5 0 0 1 .11.54l-5.819 14.547a.75.75 0 0 1-1.329.124l-3.178-4.995L.643 7.184a.75.75 0 0 1 .124-1.33L15.314.037a.5.5 0 0 1 .54.11ZM6.636 10.07l2.761 4.338L14.13 2.576zm6.787-8.201L1.591 6.602l4.339 2.76z"/>
                            </svg>
                        </button>
                    </div>                    
                </div>
            </div>        
        `;

        document.body.appendChild(chatbotContainer);
        this.setupChatUIEventListeners();
    }


    setupChatUIEventListeners() {
        document.getElementById('minimize-button').addEventListener('click', () => {
            document.getElementById('floating-chatbot').style.display = 'flex';
            document.getElementById('minimize-button').style.display = 'none';
        });

        document.getElementById('close-chatbot').addEventListener('click', () => {
            document.getElementById('floating-chatbot').style.display = 'none';
            document.getElementById('minimize-button').style.display = 'block';
        });
    }

    setupSendMessage(sendMessageCallback) {
        document.getElementById('send-message').addEventListener('click', sendMessageCallback);
    }

    getChatInput() {
        return document.getElementById('chat-input').value;
    }

    disableSendButton() {
        document.getElementById('send-message').disabled = true;
    }

    enableSendButton() {
        document.getElementById('send-message').disabled = false;
    }

    showBotResponse(botMessage) {
        const chatMessages = document.getElementById('chat-messages');
        chatMessages.innerHTML += `<div class="one-message-system">${botMessage}</div>`;
        chatMessages.scrollTop = chatMessages.scrollHeight;
    }
}
